@@ -27,6 +27,16 @@ def run():
     )
 
 
+@cli.command()
+def openshift():
+    from hflossk.site import app
+    host = os.environ['OPENSHIFT_PYTHON_IP']
+    port = int(os.environ['OPENSHIFT_PYTHON_PORT'])
+    http_server = HTTPServer(WSGIContainer(app))
+    http_server.listen(port, address=host)
+    IOLoop.instance().start()
+
+
 @cli.command()
 def new():
     # \u2714 is a check mark
@@ -65,7 +75,7 @@ def new():
 
 @cli.command()
 def version():
-    print("You are using hflossk version 0.5.0")
+    print("You are using hflossk version 0.5.1")
     print("Get more information at "
           "https://github.com/decause/hflossk")
 
